{% trans bar=foo %}
Foo {{ bar }}
{% endtrans %}

{{ _(v_index) }}
<th>{{ table_sort('date_start', _('Year')) }}</th>

<p>{% trans %}1 Hello {{ user }}!{% endtrans %}</p>

<p>{% trans user=user.username %}2 Hello {{ user }}!{% endtrans %}</p>

<p>
{% trans notrimmed book_title=book.title, author=author.name %}
3 This is {{ book_title }} by {{ author }}
{% endtrans %}
</p>

<p>
{% trans count=list|length %}
4 There is {{ count }} {{ name }} object.
{% pluralize %}
4 There are {{ count }} {{ name }} objects.
{% endtrans %}
</p>

<p>{{ _('5 Hello World!') }}</p>

{# couldnt get this one to work..#}
<p>{# _('6 Hello, %(user)s!6)|format(user=user.username) #}</p>

<p>
{% trans %}
  #{{ invoice_count }} invoice
{% pluralize %}
  #{{ invoice_count }} invoices
{% endtrans %}
</p>

</p>
{% trans trimmed %}
  #{{ trimmed_invoice_count }} trimmed invoice
{% pluralize %}
  #{{ trimmed_invoice_count }} trimmed invoices
{% endtrans %}
</p>
